function [x,edges,maps]=calcEDH(dir,n1,n2,sz,varargin)
% edh=calcEDH(dir,n1,n2,sz,...)
% 
% Read in images from n1 to n2 in dir, extract a silhoutte resizing the
% bounding box to sz, and calculate the concatenated edge direction 
% histograms.
%
% optional args:
% -  'meth' : edge detection method (default 'sobel')
% -  't' : e.d. threshold (default 10)
% -  'sc', 'st' : scales / steps for the subwindows. Default:
%    sc=[6 12 24 48], st=sc/2
% -  'tmp','tmpSil' : templates for the image/silhouette names
% -  'prep' : the function to call for silh. preprocessing
% -  'verb' : verbosity level (default 0; every verb images a msg is printed)
% -  'nocont' : ignores the mask contour (default is to add it to edge map)
%
% [edh,edges]=calcEDH(...) returns the normalized edge image
% [edh,edges,maps]=calcEDH(...) also returns the edge maps
%

method='sobel';
threshold=10;
scales=[6 12 24 48];
steps=[];
sz=200;
verb=0;
nocont=0;
extArgs{1}='';extArgs{2}='';

a=1;
while (a <= length(varargin))
  switch varargin{a},
   case 'meth',
    a=a+1;method=varargin{a};
   case 't',
    a=a+1; threshold=varargin{a};
   case 'sc',
    a=a+1; scales=varargin{a};
   case 'verb',
    a=a+1; verb=varargin{a};
   case 'st',
    a=a+1;steps=varargin{a};
   case 'tmp',
    a=a+1;
    extArgs{1}=varargin{a};
   case 'tmpSil',
    a=a+1;
    extArgs{2}=varargin{a};
   case 'prep',
    a=a+1;
    extArgs{3}=varargin{a};
   case 'nocont',
    nocont=1;
  end
  a=a+1;
end
if (isempty(steps)),  steps=scales/2; end

% build the boxes for EDH
box=buildbox([sz sz],scales,steps);


x=uint8(zeros(n2-n1+1,size(box,2)*4));

for i=n1:n2
  %fprintf(2,'%d\n',i);
  % extract and normalize the figure
  [im,sil]=extractSil(i,sz,dir,extArgs{:});
  %figure;imagesc(im);axis image;colormap gray;
  
  [x(i-n1+1,:),ed,map]=readed(im,box,threshold,method,sil,~nocont);
  if (nargout > 1)
    edges{i-n1+1}=ed;
  end
  if (nargout > 2)
    maps{i-n1+1}=map;
  end
  if (verb > 0 & mod(i+1-n1,verb)==0)
    fprintf(2,'done with %d\n',i);
  end
end
% readed returns row vectors
x=x';
