function getEDH(n,indfmt,valfmt,t,prep,sc,sz,first,last,tmp,tmpSil,tmpDir,temp)
% getEDH(n,indfmt,valfmt,t,prep,sc,sz,first,last,tmp,tmpSil,tmpDir,temp) 
% Go into 'data<n>' in the current directory, and compute EDH for each
% image.
% Save results in sparse format in data<n>/edh<n>.si
% Arguments: 
% n is the directory number, 
% t is the threshold for the edge detector [default 10]
% prep is the silhouette preparation function  [default '-' i.e. none]
% sc is the scales list (default 6,12,24,36,56)
% sz is the size (default 200)
% first, last are the indices of files to process (default all)
% tmp,tmpSil: templates for image and FG [ex%08d-r.jpg, ex%08d-fg.jpg]
% tmpDir: directory template [default data%04d]
% temp: temporary [default /scratch/gregory]
% 
% Some assumptions: 
% - 30000 images per directory


% to compile:
% /cluster-home/matlab_R13sp1/bin/mcc -h -m -I ~/matlab/iimage/ -I ~/research/lsh/matlab -I ~/research/lsh/matlab/CBIR/ -I /cluster-home/matlab_R13sp1/toolbox/matlab/iofun -I  /cluster-home/matlab_R13sp1/toolbox/images/images -I ~/matlab getEDH.m ; \rm *.{c,h}

if (nargin < 1)
  fprintf(2,'getEDH(n,indfmt,valfmt,t,prep,sc,sz,first,last,tmp,tmpSil,tmpDir,temp)\n');
  return
end

if (ischar(n))
  n=str2num(n);
end

if (nargin < 2)
  indfmt='int';
end

if (nargin < 3)
  valfmt='float';
end

if (nargin < 4)
  t=10;
elseif (ischar(t))
  t=str2num(t);
end

if (nargin < 5)
  prep=[];
elseif (strcmp(prep,'-'))
  prep=[];
end

if (nargin < 6)
  sc=[6 12 24 36 56];
elseif (ischar(sc))
    sc=str2num(sc);
end
if (nargin < 7)
  sz=200;
elseif (ischar(sz))
  sz=str2num(sz);
end

% ASSUMPTION: 30000 files per directory
offset=30000*(n-1);
if (nargin < 8)
  first=1;
  last=30000;
else
  if (ischar(first))
    first=str2num(first);
    last=str2num(last);
  end
end

if (nargin < 10)
  tmp='ex%08d-r.jpg';
end
if (nargin < 11)
  tmpSil='ex%08d-fg.jpg';
end
if (nargin < 12)
  tmpDir='data%04d';
end

if (nargin < 13)
  temp='/scratch/gregory';
end

%df=dir(sprintf('data%04d/*-fg.jpg',n));
buf=sprintf('Processing %d through %d\n',first+offset,last+offset);
fwrite(2,[buf 10]);pause(0);

% ASSUMPTION: known username
fname=sprintf('edh%04d_%d_%d.si',n,first+offset,last+offset);
edh=fopen(sprintf('%s/%s',temp,fname),'wb');

for i=first:last
  % calculate the EDH for this image
  % see comments in calcEDH for argument descriptions
  z=calcEDH(sprintf(tmpDir,n),i+offset,i+offset,sz,'tmp',tmp,'tmpSil',tmpSil,'sc',sc,'prep',prep,'t',t,'nocont');

  % write it into the file
  writeSparse(edh,z,indfmt,valfmt);
  if (mod(i,100)==0)
    buf=sprintf('done %d',i);
    fwrite(2,[buf 10]);pause(0);
  end
end
fclose(edh);
fwrite(2,['Finished, copying' 10]);pause(0);

dirname=sprintf(tmpDir,n);
if (~strcmp(temp,dirname))
  eval(sprintf(['!/bin/mv  %s/%s ' dirname '/%s'],temp,fname,fname));
end
fwrite(2,['Done' 10]);pause(0);
