# runBVH.py
#
# this script goes over a list of .bvh files, and for each file:
# - cleans the figure
# - loads the BVH sequence;
# - for every frame in the sequence, applies the pose and saves the parameters
#
# Note: this saves a) the pose (angles), b) the 3D joint location (XYZ) in 
# "canonical" coordinate frame i.e., normalized so that Hip is at x=0,z=0 and
# the feet are on the floor.
# All the files go into a directory named after each sequence
#
# The BVH-list file has on each line <filename> <number> where the number
# specifies how the BVH is loaded (something about axes alignment)

# (C) Greg Shakhnarovich, TTI-Chicago, 2007

import poser
import sys
#

# directory where Poser-related stuff resides
poserDir = 'c:\\greg\\Poser'

sys.path = sys.path + [poserDir + '\\py']
from humanparam import *
from scenemanip import *


paramlist=readParamList(poserDir + "\\paramList.txt")

scene=poser.Scene()

# the file which tells us what sequences to include
metafile=open("c:\\greg\\pose\\bvh\\testbvh.txt","r");
bvhnames=metafile.readlines()
metafile.close()

# the figure used in all sequences
FIGURE = poserDir+"\\figureBVH.pz3"
# directory where the poses are written
outDir="c:\\greg\\pose\\bvh\\poses\\"

poser.SaveDocument("c:\\greg\\Poser\\bvh\\___saved.pz3");

for b in range(0,len(bvhnames)):
    # clean up, discard changes
    poser.CloseDocument(1);
    # load the figure;
    poser.OpenDocument(FIGURE)
    
    fig=scene.Figure("Figure 1");
    scene.SelectFigure(fig);

    # load the BVH file
    [bvhname,armsalign]=bvhnames[b].strip().split()
    # find out the name of the sequence
    pth = (bvhname.split('.'))[0].split('\\');
    seqname = pth[len(pth)-1];
    
    importer = scene.ImExporter()
    options = importer.ImportOptions("BVH", None)
    options[11] = int(armsalign)
    options[12] = 1
    importer.Import("BVH", None, bvhname, options);

    if not os.path.exists(outDir+seqname):
        os.makedirs(outDir+seqname)    
    # have one file with all poses for this sequence
    angf=open(outDir+seqname+"\\bvhAngles.txt","w");
    # file with XYZ in canonical orientation
    normxyz=open(outDir+seqname+"\\bvhNormXYZ.txt","w");

    for f in range (0, scene.NumFrames()):
        # apply the pose in the frame
        scene.SetFrame(f)
        
	# translate: make the hip at x=0,z=0
        fig.Actor("Hip").SetParameter("xTran",0);
        fig.Actor("Hip").SetParameter("zTran",0);
        scene.DrawAll();
        
	# record the pose angles and joint locations
        writeparam(angf,paramlist);

        # save joint locations in canonical orientation and location
        # uncomment next line if want always frontal orientation
        #fig.Actor("Hip").SetParameter("yRotate",0);
        # uncomment next line if want always feet touching floor
        #fig.DropToFloor();
        scene.DrawAll();
        logXYZ(normxyz,units='meter');

	# render the frame
	imtemplate = "seq%08d"
	frname=outDir+seqname+"\\"+imtemplate % (f+1)
        # the next command will actually render the image
	# stereoshot(frname,sil=True,stereo=False);

        # end of <for f> loop over frames

    angf.close()
    normxyz.close()
    
    # end of <for b> loop over BVH files

#restore the status before the script started
poser.RevertDocument();

