# scenemanip.py
#
# This file contains functions used in manipulating the Poser scene, 

# (C) Greg Shakhnarovich, TTI-Chicago, 2008

import poser
import sys
False=0
True=1
from random import uniform

scene = poser.Scene()

def setlight(lname):
    # set the parameters of the given light to a random values within fixed
    # bounds
    light = scene.Actor(lname);
    light.SetParameter("xRotate",uniform(-40,40));
    light.SetParameter("yRotate",uniform(-50,50));
    light.SetParameter("zRotate",uniform(-60,60));
    light.SetParameter("Intensity",uniform(.70,1));



def stereoshot(frname,disp=-.05,sil=False,stereo=True):
    # saving the image from the current camera. May also save silhouette
    # and/or a second stereo image
    if stereo:
        # produce a second shot moving the camera to the right
        cam = scene.CurrentCamera();
        currX = cam.Parameter('DollyX').Value()
        cam.SetParameter('DollyX',currX+disp);
        scene.DrawAll()
        scene.AntialiasNow()
        scene.SaveImage("jpg",frname+'-l.jpg')
        cam.SetParameter('DollyX',currX);
    
    scene.DrawAll()
    scene.AntialiasNow()    
    scene.SaveImage("jpg",frname+'-r.jpg')
    if sil:
        # also save the silhouette
        scene.SetDisplayStyle(poser.kDisplayCodeSILHOUETTE)
        scene.DrawAll()
        silname = frname+'-fg.jpg'
        scene.SaveImage("jpg",silname)
        scene.SetDisplayStyle(poser.kDisplayCodeTEXTURESHADED)


shirts = ["P5MaleDressShirt2",
          "P5MaleTShirt",
          "P5MaleDBSuitCoat",
          "P5MaleSBSuitCoat",
          "P5MalePoloShirt",
          "P5MalePajamaTop",
          "P5MaleNehruShirt",
          "P5MaleLeatherCoat",
          "P5MaleWinterCoat",
          "P5MaleLightJacket"
          ]

def setShirt(gender='Male'):
    # change shirt (must be Figure 3)
    scene.SelectFigure(scene.Figure("Figure 3"));
    scene.DeleteCurrentFigure();
    k = int(uniform(0,len(shirts)));
    scene.LoadLibraryFigure("C:\\Program Files\\Curious Labs\\Poser 5\\Runtime\\libraries\\charachter\\Clothing- Conforming\\Clothing- P5 "+gender+"\\"+shirts[k]+".crz");
    shirt= scene.Figure("Figure 3");
    shirt.SetConformTarget(scene.Figure("Figure 1"));

pants = ["P5MaleBathingSuit",
         "P5MaleJeans",
         "P5MaleChinos",
         "P5MaleCombatPants",
         "P5MaleCrocodilePants",
         "P5MaleDressSuitPants",
         "P5MalePajamaBottoms",
         "P5MaleSlacks",
         "P5ManShorts"]


def setPants(gender='Male'):
    # change pants (must be Figure 2)
    scene.SelectFigure(scene.Figure("Figure 2"));
    scene.DeleteCurrentFigure();
    k = int(uniform(0,len(pants)));
    scene.LoadLibraryFigure("C:\\Program Files\\Curious Labs\\Poser 5\\Runtime\\libraries\\charachter\\Clothing- Conforming\\Clothing- P5 "+gender+"\\"+pants[k]+".crz");
    pant= scene.Figure("Figure 2");
    pant.SetConformTarget(scene.Figure("Figure 1"));

shoes=["P5MaleCowBoyBoot",
       "P5MaleDressShoe2",
       "P5MaleHikingBoot",
       "P5MaleRunShoe",
       "P5MaleSandal",
       "P5MaleSock"
       ]

def setShoes(gender='Male'):
    # change shoes. must be Figures 4 (L) and 5 (R)
    scene.SelectFigure(scene.Figure("Figure 4"));
    scene.DeleteCurrentFigure();
    k = int(uniform(0,len(shoes)));
    scene.LoadLibraryFigure("C:\\Program Files\\Curious Labs\\Poser 5\\Runtime\\libraries\\charachter\\Clothing- Conforming\\Clothing- P5 "+gender+"\\"+shoes[k]+"L.crz");
    shoe= scene.Figure("Figure 4");
    shoe.SetConformTarget(scene.Figure("Figure 1"));

    scene.SelectFigure(scene.Figure("Figure 5"));
    scene.DeleteCurrentFigure();
    scene.LoadLibraryFigure("C:\\Program Files\\Curious Labs\\Poser 5\\Runtime\\libraries\\charachter\\Clothing- Conforming\\Clothing- P5 "+gender+"\\"+shoes[k]+"R.crz");
    shoe= scene.Figure("Figure 5");
    shoe.SetConformTarget(scene.Figure("Figure 1"));



def setHair():
    # hair
    scene.SelectFigure(scene.Figure("Figure 1"));
    scene.SelectActor(scene.Figure("Figure 1").Actor("hair"));
    scene.DeleteCurrentProp()
    k = int(uniform(0,4))
    scene.LoadLibraryHair("C:\\Program Files\\Curious Labs\\Poser 5\\Runtime\\libraries\\hair\\Poser 4 Hair\\Hair"+str(k+1)+".hr2")
            
